Oed

Type Alias Oed 

pub type Oed = EnumBitfieldStruct<u8, Oed_SPEC>;

Aliased Type

#[repr(transparent)]
pub struct Oed(pub u8, _);

Tuple Fields

0: u8

Implementations

Source

impl Oed

pub const _0: Self

Endian formats are the same between the chip and input data.

pub const _1: Self

Endian formats are different between the chip and input data.