Cef

Type Alias Cef 

pub type Cef = EnumBitfieldStruct<u8, Cef_SPEC>;

Aliased Type

#[repr(transparent)]
pub struct Cef(pub u8, _);

Tuple Fields

0: u8

Implementations

Source

impl Cef

pub const _0: Self

All of the output data has not been read out.

pub const _1: Self

All of the output data has been read out.