Iint

Type Alias Iint 

pub type Iint = EnumBitfieldStruct<u8, Iint_SPEC>;

Aliased Type

#[repr(transparent)]
pub struct Iint(pub u8, _);

Tuple Fields

0: u8

Implementations

Source

impl Iint

pub const _0: Self

Number of data units in the input FIFO has not become equal to or smaller than the specified triggering number.

pub const _1: Self

Number of data units in the input FIFO has become equal to or smaller than the specified triggering number.