Oint

Type Alias Oint 

pub type Oint = EnumBitfieldStruct<u8, Oint_SPEC>;

Aliased Type

#[repr(transparent)]
pub struct Oint(pub u8, _);

Tuple Fields

0: u8

Implementations

Source

impl Oint

pub const _0: Self

Number of data units in the output FIFO has not become equal to or greater than the specified triggering number.

pub const _1: Self

Number of data units in the output FIFO has become equal to or greater than the specified triggering number.