pub type Oed = EnumBitfieldStruct<u8, Oed_SPEC>;
#[repr(transparent)]pub struct Oed(pub u8, _);
0: u8
Endian formats are the same between the chip and input data.
Endian formats are different between the chip and input data.