pub type Srcod = RegValueT<Srcod_SPEC>;Expand description
Output Data Register
Aliased Type
pub struct Srcod { /* private fields */ }Implementations
Sourceimpl Srcod
impl Srcod
Sourcepub fn srcod(
self,
) -> RegisterField<0, 0xffffffff, 1, 0, u32, u32, Srcod_SPEC, R>
pub fn srcod( self, ) -> RegisterField<0, 0xffffffff, 1, 0, u32, u32, Srcod_SPEC, R>
SRCOD is a 32-bit read-only register used to output the data after sampling rate conversion. The data in the 16-stage output data FIFO is read through SRCOD. When the number of data in the output data FIFO is zero after the start of conversion, the value previously read is read again.